@@ -1,9 +1,11 @@
 #![allow(unused_imports)]
+
 use std::io::stdin;
 
-/// Importing token_name method.
-mod xrc20;
-use xrc20::name::token_name;
+mod lib;
+/// Impoting name module which consits token_name method.
+use lib::xrc20::name;
+
 
 #[allow(unused_must_use)]
 fn main() {
@@ -11,8 +13,8 @@ fn main() {
     let mut token_address = String::new();
     println!("enter token address: ");
     stdin().read_line(&mut token_address);
-
+    
     // Passing user value as function required.
-    let name = token_name(token_address).unwrap();
-    println!("token name: {}", name);
-}
+    let token_name = name::token_name(token_address).unwrap();
+    println!("token name: {}", token_name);
+}
\ No newline at end of file
